@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from django.http import Http404, HttpResponse
 from django.urls import path
 
@@ -13,8 +15,7 @@ def test_view_http401(request):
 
 
 def test_view_that_deletes_is_enabled(request):
-    if hasattr(request, "_cors_enabled"):
-        del request._cors_enabled
+    del request._cors_enabled
     return HttpResponse()
 
 
